plot.burndown: Scan burndown data file

Description Usage Arguments Details Value Author(s) References See Also Examples

Description

Plot a burndown object

Usage

1
2
3
4
5
## S3 method for class 'burndown'
plot(x, col=NULL, draw.plan=TRUE, draw.regression=FALSE,
              draw.lastupdate=FALSE, t.stop="",
              mar=c(3, 3, 1, 1), mgp=c(2, 0.7, 0),
              debug=FALSE, ...)

Arguments

x

A burndown object.

col

Colours for items, starting with the first key in the file (which will be at the bottom of the chart). If not specified, the hcl scheme will be used, to generate colours that are distinct, that show up reasonably well on a monitor.

draw.plan

Set TRUE to draw the plan, as a descending with a horizontal intercept.

draw.regression

Set TRUE to draw a regression line of the realized effort.

draw.lastupdate

Set TRUE to draw the last update (which otherwise requires a sharp eye).

t.stop

Maximum time for graph (defaults to deadline if not given)

mar

margin value as supplied to par.

mgp

axis label placement as supplied to par.

debug

Set TRUE to monitor the work.

...

Extra things handed down.

Details

Plots a burndown chart.

Value

No return value.

Author(s)

Dan Kelley Dan.Kelley@Dal.Ca

References

http://alistair.cockburn.us/crystal/articles/evabc/earnedvalueandburncharts.htm.

See Also

read.burndown summary.burndown

Examples

1
2
3
4

dankelley/burndown documentation built on May 14, 2019, 4:08 p.m.