Description Usage Arguments Details Value Author(s) References See Also Examples
Plot a burndown object
1 2 3 4 5 |
x |
A burndown object. |
col |
Colours for items, starting with the first key in the
file (which will be at the bottom of the chart). If not specified,
the |
draw.plan |
Set TRUE to draw the plan, as a descending with a horizontal intercept. |
draw.regression |
Set TRUE to draw a regression line of the realized effort. |
draw.lastupdate |
Set TRUE to draw the last update (which otherwise requires a sharp eye). |
t.stop |
Maximum time for graph (defaults to deadline if not given) |
mar |
margin value as supplied to |
mgp |
axis label placement as supplied to |
debug |
Set TRUE to monitor the work. |
... |
Extra things handed down. |
Plots a burndown chart.
No return value.
Dan Kelley Dan.Kelley@Dal.Ca
http://alistair.cockburn.us/crystal/articles/evabc/earnedvalueandburncharts.htm.
read.burndown
summary.burndown
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.